import { ElementRef } from '@angular/core';
/**
 * Use this for configuring the confirmation popover defaults
 *
 * Use it like so:
 * ```
 * providers: [
 *   provide(ConfirmOptions, {
 *     useFactory: (): ConfirmOptions => {
 *       return new ConfirmOptions({
 *         // focus the confirm button by default. See below for an explanation of all options.
 *         focusButton: 'confirm'
 *       });
 *     }
 *   })
 * ]
 * ```
 */
export declare class ConfirmOptions {
    /**
     * The popover title
     */
    title: string;
    /**
     * The popover message
     */
    message: string;
    /**
     * The popover confirmation button text
     */
    confirmText: string;
    /**
     * The popover cancel button text
     */
    cancelText: string;
    /**
     * The popover confirm button type e.g. `success`, `danger` etc
     */
    confirmButtonType: string;
    /**
     * The popover cancel button type  e.g. `success`, `danger` etc
     */
    cancelButtonType: string;
    /**
     * The popover placement. Can be `top`, `bottom`, `left`, `right`
     */
    placement: string;
    /**
     * Which button to cancel. Can be either `confirm` or `cancel`
     */
    focusButton: string;
    /**
     * Whether to hide the confirmation button
     */
    hideConfirmButton: boolean;
    /**
     * Whether to hide the cancel button
     */
    hideCancelButton: boolean;
    /**
     * @param options the options object to set on the instance of the confirm options
     */
    constructor(options?: Object);
}
/**
 * @private
 */
export declare class PopoverConfirmOptions extends ConfirmOptions {
    onConfirm: Function;
    onCancel: Function;
    hostElement: ElementRef;
}
